@@ -2,16 +2,6 @@ from .base import BaseClient as __BaseClient
 from typing import List as _List
 
 
-class ErrorList:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "errors" in data:
-            self.errors: _List[Error] = [Error(datum) for datum in data["errors"]]
-        else:
-            self.errors: _List[Error] = []
-
-
 class Error:
     def __init__(self, data):
         super().__init__()
@@ -30,6 +20,24 @@ class Error:
             self.details: str = None
 
 
+class ReportDocumentEncryptionDetails:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "standard" in data:
+            self.standard: str = str(data["standard"])
+        else:
+            self.standard: str = None
+        if "initializationVector" in data:
+            self.initializationVector: str = str(data["initializationVector"])
+        else:
+            self.initializationVector: str = None
+        if "key" in data:
+            self.key: str = str(data["key"])
+        else:
+            self.key: str = None
+
+
 class Report:
     def __init__(self, data):
         super().__init__()
@@ -168,17 +176,7 @@ class ReportSchedule:
             self.nextReportCreationTime: str = None
 
 
-class ReportScheduleList:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "reportSchedules" in data:
-            self.reportSchedules: _List[ReportSchedule] = [ReportSchedule(datum) for datum in data["reportSchedules"]]
-        else:
-            self.reportSchedules: _List[ReportSchedule] = []
-
-
-class CreateReportResponse:
+class CreateReportResult:
     def __init__(self, data):
         super().__init__()
         self.data = data
@@ -192,17 +190,97 @@ class GetReportsResponse:
     def __init__(self, data):
         super().__init__()
         self.data = data
-        if "reports" in data:
-            self.reports: ReportList = ReportList(data["reports"])
+        if "payload" in data:
+            self.payload: ReportList = ReportList(data["payload"])
         else:
-            self.reports: ReportList = None
+            self.payload: ReportList = None
         if "nextToken" in data:
             self.nextToken: str = str(data["nextToken"])
         else:
             self.nextToken: str = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
 
 
-class CreateReportScheduleResponse:
+class CreateReportResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: CreateReportResult = CreateReportResult(data["payload"])
+        else:
+            self.payload: CreateReportResult = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class CancelReportResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class CancelReportScheduleResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: Report = Report(data["payload"])
+        else:
+            self.payload: Report = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportSchedulesResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: ReportScheduleList = ReportScheduleList(data["payload"])
+        else:
+            self.payload: ReportScheduleList = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class GetReportScheduleResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: ReportSchedule = ReportSchedule(data["payload"])
+        else:
+            self.payload: ReportSchedule = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class CreateReportScheduleResult:
     def __init__(self, data):
         super().__init__()
         self.data = data
@@ -212,6 +290,20 @@ class CreateReportScheduleResponse:
             self.reportScheduleId: str = None
 
 
+class CreateReportScheduleResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: CreateReportScheduleResult = CreateReportScheduleResult(data["payload"])
+        else:
+            self.payload: CreateReportScheduleResult = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
 class ReportDocument:
     def __init__(self, data):
         super().__init__()
@@ -224,19 +316,51 @@ class ReportDocument:
             self.url: str = str(data["url"])
         else:
             self.url: str = None
+        if "encryptionDetails" in data:
+            self.encryptionDetails: ReportDocumentEncryptionDetails = ReportDocumentEncryptionDetails(
+                data["encryptionDetails"]
+            )
+        else:
+            self.encryptionDetails: ReportDocumentEncryptionDetails = None
         if "compressionAlgorithm" in data:
             self.compressionAlgorithm: str = str(data["compressionAlgorithm"])
         else:
             self.compressionAlgorithm: str = None
 
 
+class GetReportDocumentResponse:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "payload" in data:
+            self.payload: ReportDocument = ReportDocument(data["payload"])
+        else:
+            self.payload: ReportDocument = None
+        if "errors" in data:
+            self.errors: ErrorList = ErrorList(data["errors"])
+        else:
+            self.errors: ErrorList = None
+
+
+class ErrorList(list, _List["Error"]):
+    def __init__(self, data):
+        super().__init__([Error(datum) for datum in data])
+        self.data = data
+
+
 class ReportList(list, _List["Report"]):
     def __init__(self, data):
         super().__init__([Report(datum) for datum in data])
         self.data = data
 
 
-class Reports20210630Client(__BaseClient):
+class ReportScheduleList(list, _List["ReportSchedule"]):
+    def __init__(self, data):
+        super().__init__([ReportSchedule(datum) for datum in data])
+        self.data = data
+
+
+class Reports20200904Client(__BaseClient):
     def getReports(
         self,
         reportTypes: _List[str] = None,
@@ -247,7 +371,7 @@ class Reports20210630Client(__BaseClient):
         createdUntil: str = None,
         nextToken: str = None,
     ):
-        url = "/reports/2021-06-30/reports".format()
+        url = "/reports/2020-09-04/reports".format()
         params = {}
         if reportTypes is not None:
             params["reportTypes"] = ",".join(map(str, reportTypes))
@@ -266,174 +390,176 @@ class Reports20210630Client(__BaseClient):
         response = self.request(url, method="GET", params=params)
         return {
             200: GetReportsResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: GetReportsResponse,
+            401: GetReportsResponse,
+            403: GetReportsResponse,
+            404: GetReportsResponse,
+            415: GetReportsResponse,
+            429: GetReportsResponse,
+            500: GetReportsResponse,
+            503: GetReportsResponse,
         }[response.status_code](self._get_response_json(response))
 
     def createReport(
         self,
         data: CreateReportSpecification,
     ):
-        url = "/reports/2021-06-30/reports".format()
+        url = "/reports/2020-09-04/reports".format()
         params = {}
         response = self.request(url, method="POST", data=data.data)
         return {
             202: CreateReportResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: CreateReportResponse,
+            401: CreateReportResponse,
+            403: CreateReportResponse,
+            404: CreateReportResponse,
+            415: CreateReportResponse,
+            429: CreateReportResponse,
+            500: CreateReportResponse,
+            503: CreateReportResponse,
         }[response.status_code](self._get_response_json(response))
 
     def getReport(
         self,
         reportId: str,
     ):
-        url = "/reports/2021-06-30/reports/{reportId}".format(
+        url = "/reports/2020-09-04/reports/{reportId}".format(
             reportId=reportId,
         )
         params = {}
         response = self.request(url, method="GET", params=params)
         return {
-            200: Report,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportResponse,
+            400: GetReportResponse,
+            401: GetReportResponse,
+            403: GetReportResponse,
+            404: GetReportResponse,
+            415: GetReportResponse,
+            429: GetReportResponse,
+            500: GetReportResponse,
+            503: GetReportResponse,
         }[response.status_code](self._get_response_json(response))
 
     def cancelReport(
         self,
         reportId: str,
     ):
-        url = "/reports/2021-06-30/reports/{reportId}".format(
+        url = "/reports/2020-09-04/reports/{reportId}".format(
             reportId=reportId,
         )
         params = {}
         response = self.request(url, method="DELETE", data=data.data)
         return {
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: CancelReportResponse,
+            400: CancelReportResponse,
+            401: CancelReportResponse,
+            403: CancelReportResponse,
+            404: CancelReportResponse,
+            415: CancelReportResponse,
+            429: CancelReportResponse,
+            500: CancelReportResponse,
+            503: CancelReportResponse,
         }[response.status_code](self._get_response_json(response))
 
     def getReportSchedules(
         self,
         reportTypes: _List[str],
     ):
-        url = "/reports/2021-06-30/schedules".format()
+        url = "/reports/2020-09-04/schedules".format()
         params = {}
         if reportTypes is not None:
             params["reportTypes"] = ",".join(map(str, reportTypes))
         response = self.request(url, method="GET", params=params)
         return {
-            200: ReportScheduleList,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportSchedulesResponse,
+            400: GetReportSchedulesResponse,
+            401: GetReportSchedulesResponse,
+            403: GetReportSchedulesResponse,
+            404: GetReportSchedulesResponse,
+            415: GetReportSchedulesResponse,
+            429: GetReportSchedulesResponse,
+            500: GetReportSchedulesResponse,
+            503: GetReportSchedulesResponse,
         }[response.status_code](self._get_response_json(response))
 
     def createReportSchedule(
         self,
         data: CreateReportScheduleSpecification,
     ):
-        url = "/reports/2021-06-30/schedules".format()
+        url = "/reports/2020-09-04/schedules".format()
         params = {}
         response = self.request(url, method="POST", data=data.data)
         return {
             201: CreateReportScheduleResponse,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            400: CreateReportScheduleResponse,
+            401: CreateReportScheduleResponse,
+            403: CreateReportScheduleResponse,
+            404: CreateReportScheduleResponse,
+            415: CreateReportScheduleResponse,
+            429: CreateReportScheduleResponse,
+            500: CreateReportScheduleResponse,
+            503: CreateReportScheduleResponse,
         }[response.status_code](self._get_response_json(response))
 
     def getReportSchedule(
         self,
         reportScheduleId: str,
     ):
-        url = "/reports/2021-06-30/schedules/{reportScheduleId}".format(
+        url = "/reports/2020-09-04/schedules/{reportScheduleId}".format(
             reportScheduleId=reportScheduleId,
         )
         params = {}
         response = self.request(url, method="GET", params=params)
         return {
-            200: ReportSchedule,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportScheduleResponse,
+            400: GetReportScheduleResponse,
+            401: GetReportScheduleResponse,
+            403: GetReportScheduleResponse,
+            404: GetReportScheduleResponse,
+            415: GetReportScheduleResponse,
+            429: GetReportScheduleResponse,
+            500: GetReportScheduleResponse,
+            503: GetReportScheduleResponse,
         }[response.status_code](self._get_response_json(response))
 
     def cancelReportSchedule(
         self,
         reportScheduleId: str,
     ):
-        url = "/reports/2021-06-30/schedules/{reportScheduleId}".format(
+        url = "/reports/2020-09-04/schedules/{reportScheduleId}".format(
             reportScheduleId=reportScheduleId,
         )
         params = {}
         response = self.request(url, method="DELETE", data=data.data)
         return {
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: CancelReportScheduleResponse,
+            400: CancelReportScheduleResponse,
+            401: CancelReportScheduleResponse,
+            403: CancelReportScheduleResponse,
+            404: CancelReportScheduleResponse,
+            415: CancelReportScheduleResponse,
+            429: CancelReportScheduleResponse,
+            500: CancelReportScheduleResponse,
+            503: CancelReportScheduleResponse,
         }[response.status_code](self._get_response_json(response))
 
     def getReportDocument(
         self,
         reportDocumentId: str,
     ):
-        url = "/reports/2021-06-30/documents/{reportDocumentId}".format(
+        url = "/reports/2020-09-04/documents/{reportDocumentId}".format(
             reportDocumentId=reportDocumentId,
         )
         params = {}
         response = self.request(url, method="GET", params=params)
         return {
-            200: ReportDocument,
-            400: ErrorList,
-            401: ErrorList,
-            403: ErrorList,
-            404: ErrorList,
-            415: ErrorList,
-            429: ErrorList,
-            500: ErrorList,
-            503: ErrorList,
+            200: GetReportDocumentResponse,
+            400: GetReportDocumentResponse,
+            401: GetReportDocumentResponse,
+            403: GetReportDocumentResponse,
+            404: GetReportDocumentResponse,
+            415: GetReportDocumentResponse,
+            429: GetReportDocumentResponse,
+            500: GetReportDocumentResponse,
+            503: GetReportDocumentResponse,
         }[response.status_code](self._get_response_json(response))
