@@ -147,7 +147,7 @@ class SolicitationsV1Client(__BaseClient):
             429: GetSolicitationActionsForOrderResponse,
             500: GetSolicitationActionsForOrderResponse,
             503: GetSolicitationActionsForOrderResponse,
-        }[response.status_code](self.__get_response_json(response))
+        }[response.status_code](self._get_response_json(response))
 
     def createProductReviewAndSellerFeedbackSolicitation(
         self,
@@ -171,4 +171,4 @@ class SolicitationsV1Client(__BaseClient):
             429: CreateProductReviewAndSellerFeedbackSolicitationResponse,
             500: CreateProductReviewAndSellerFeedbackSolicitationResponse,
             503: CreateProductReviewAndSellerFeedbackSolicitationResponse,
-        }[response.status_code](self.__get_response_json(response))
+        }[response.status_code](self._get_response_json(response))
