@@ -88,4 +88,4 @@ class VendorTransactionStatusV1Client(__BaseClient):
             429: GetTransactionResponse,
             500: GetTransactionResponse,
             503: GetTransactionResponse,
-        }[response.status_code](self.__get_response_json(response))
+        }[response.status_code](self._get_response_json(response))
